package InSilicoSpectro::Databanks;

use warnings;
use strict;

=head1 NAME

InSilicoSpectro::Databanks - parsing protein/nucleotides sequence databanks (fasta, uniprot...)

=head1 VERSION

=cut

our $VERSION = '0.0.11';

=head1 SYNOPSIS

Quick summary of what the module does.

Perhaps a little code snippet.

    use InSilicoSpectro::Databanks;

    my $foo = InSilicoSpectro::Databanks->new();
    ...

=head1 EXPORT

A list of functions that can be exported.  You can delete this section
if you don't export anything, such as for a purely object-oriented module.

=head1 FUNCTIONS


=head1 AUTHOR

Alexandre Masselot, C<< <alexandre.masselot@genebio.com> >>

=head1 BUGS

Please report any bugs or feature requests to
C<bug-insilicospectro-databanks@rt.cpan.org>, or through the web interface at
L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=InSilicoSpectro-Databanks>.
I will be notified, and then you'll automatically be notified of progress on
your bug as I make changes.

=head1 ACKNOWLEDGEMENTS

=head1 COPYRIGHT & LICENSE

Copyright 2006 Alexandre Masselot, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.

=cut

1; # End of InSilicoSpectro::Databanks
